==> soliq_id-1.4.36.tar.gz: lib/src/screens/widgets/custom_button.dart <==
import 'package:flutter/material.dart';

class AppButton extends StatelessWidget {
  const AppButton({
    Key? key,
    this.onTap,
    this.background,
    this.isLoading = false,
    this.isDisabled = false,
    required this.title,
  }) : super(key: key);
  final GestureTapCallback? onTap;
  final Color? background;
  final bool? isLoading;
  final bool? isDisabled;
  final String title;

  @override
  Widget build(BuildContext context) {
    return Container(
      margin: const EdgeInsets.only(left: 28, right: 28),
      child: Stack(
        alignment: Alignment.centerRight,
        children: [
          ElevatedButton(
              style: ElevatedButton.styleFrom(
                  backgroundColor: background ?? Colors.grey,
                  minimumSize: Size(MediaQuery.of(context).size.width - 32, 56),
                  shape: const RoundedRectangleBorder(
                      borderRadius: BorderRadius.all(Radius.circular(12)))),
              onPressed: !(isDisabled ?? false) ? onTap : null,
              child: Center(
                child: Text(
                  title,
                  style: const TextStyle(
                      fontWeight: FontWeight.w500,
                      fontSize: 16,
                      color: Colors.white),
                ),
              )),
          if (isLoading ?? false)
            Container(
                margin: const EdgeInsets.only(right: 12),
                width: 24,
                height: 24,
                child: const CircularProgressIndicator()),
        ],
      ),
    );
  }
}

==> soliq_id-1.4.37.tar.gz: lib/src/screens/widgets/custom_button.dart <==
import 'package:flutter/material.dart';

import '../../utils/color_utils.dart';

class AppButton extends StatelessWidget {
  const AppButton({
    Key? key,
    this.onTap,
    this.background,
    this.isLoading = false,
    this.isDisabled = false,
    required this.title,
  }) : super(key: key);
  final GestureTapCallback? onTap;
  final Color? background;
  final bool? isLoading;
  final bool? isDisabled;
  final String title;

  @override
  Widget build(BuildContext context) {
    return Container(
      margin: const EdgeInsets.only(left: 28, right: 28),
      child: Stack(
        alignment: Alignment.centerRight,
        children: [
          ElevatedButton(
              style: ElevatedButton.styleFrom(
                  backgroundColor: background ?? AppColor.custom_redColor,
                  minimumSize: Size(MediaQuery.of(context).size.width - 32, 56),
                  shape: const RoundedRectangleBorder(
                      borderRadius: BorderRadius.all(Radius.circular(12)))),
              onPressed: !(isDisabled ?? false) ? onTap : null,

              child: Center(
                child: Text(
                  title,
                  style: const TextStyle(
                      fontWeight: FontWeight.w500,
                      fontSize: 16,
                      color: Colors.white),
                ),
              )),
          if(isLoading ?? false) Container(
              margin: const EdgeInsets.only(right: 12),
              width: 24,
              height: 24,
              child: const CircularProgressIndicator()),
        ],
      ),
    );
  }
}
